# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-05 08:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0037_auto_20191202_1930'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaignrecord',
            name='share_qrcode',
            field=models.ImageField(blank=True, null=True, upload_to=b'bee_django_crm/campaign_record/share_qrcode', verbose_name=b'\xe5\xb0\x8f\xe7\xa8\x8b\xe5\xba\x8f\xe4\xba\x8c\xe7\xbb\xb4\xe7\xa0\x81'),
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='status',
            field=models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe6\x8f\x90\xe5\x8f\x96'), (3, b'\xe5\xb7\xb2\xe6\xb6\x88\xe8\xb4\xb9')], default=1),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-02 07:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0035_auto_20191128_1829'),
    ]

    operations = [
        migrations.AddField(
            model_name='wxuser',
            name='avatar_url',
            field=models.URLField(null=True, verbose_name=b'\xe5\xa4\xb4\xe5\x83\x8f\xe9\x93\xbe\xe6\x8e\xa5'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.conf.urls import include, url
from django.contrib.auth import views as auth_views

from . import wxapp


urlpatterns = [
    url(r'^login$', wxapp.login),
    url(r'^test$', wxapp.test),
    # url(r'^share/image/(?P<reward_id>[0-9]+)$', wxapp.share_image),

    url(r'^campaign/my/detail/(?P<wxuser_id>[0-9]+)/(?P<reward_id>[0-9]+)$', wxapp.campaign_my_detail),
    url(r'^campaign/detail/(?P<pk>[0-9]+)$', wxapp.CampaignRecordDetail.as_view()),
    url(r'^campaign/create$', wxapp.campaign_record_create),
    url(r'^campaign/bind/user$', wxapp.campaign_bind_user),
    url(r'^campaign/bind/preuser$', wxapp.campaign_bind_preuser),

    url(r'^bargain/list/(?P<campaign_id>[0-9]+)$', wxapp.BargainList.as_view()),
    url(r'^bargain/detail/(?P<pk>[0-9]+)$', wxapp.BargainRecordDetail.as_view()),
    url(r'^bargain/create$', wxapp.bargain_record_create),
]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

__author__ = 'zhangyue'

# Create your models here.
import os, csv, random, json, requests, datetime, pytz
from datetime import timedelta
from django.db import models, transaction
from django.db.models import Sum
from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from django.conf import settings
from smart_selects.db_fields import ChainedForeignKey
from django.core.files.storage import FileSystemStorage
from dss.Serializer import serializer
from django.utils import timezone
from bee_django_richtext.custom_fields import RichTextField

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')
# 性别
PREUSER_GENDER_CHOICES = ((1, '男'), (2, '女'))
# 意向
PREUSER_GRADE_CHOICES = ((0, '无'), (1, '弱'), (2, '强'))
# 申请表的问题类型
APPLICATION_QUESTION_INPUT_TYPE_CHOICES = ((1, '输入框'), (2, '单选（圆钮）'), (3, '单选（下拉）'), (4, "多选（方钮）"))
# 级别
PREUSER_LEVEL_CHOICES = ((0, '全部'), (1, '小白'), (2, '申请'), (3, '缴费'), (4, '课程卡'))
# 合同周期
CONTRACT_PERIOD_CHOICES = ((1, '天'), (7, '周'), (31, '月'), (9999, '长期'))
CRM_POSTER_PHOTO_PATH = "bee_django_crm/poster_photo"  # 生成海报的文件路径，前面不带/
test = ''


def get_user_table():
    return settings.AUTH_USER_MODEL


def get_user_name_field():
    if settings.USER_NAME_FIELD:
        return settings.USER_NAME_FIELD
    else:
        return settings.CRM_USER_NAME_FIELD


# 省市区联动
class Province(models.Model):
    name = models.CharField(max_length=180, null=True)

    class Meta:
        db_table = 'bee_django_crm_province'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return self.name


class City(models.Model):
    province = models.ForeignKey(Province)
    name = models.CharField(max_length=180, null=True)

    class Meta:
        db_table = 'bee_django_crm_city'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return self.name


class District(models.Model):
    city = models.ForeignKey(City)
    # city=ChainedForeignKey(City,chained_field='continent',show_all=False,auto_choose=True,sort=True)
    name = models.CharField(max_length=180, null=True)

    class Meta:
        db_table = 'bee_django_crm_district'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return self.name


PREUSER_PAY_STATUS_CHOICES = ((0, '未缴费'), (1, "全款缴清"), (2, "分期中"))


# 预备学员
class PreUser(models.Model):
    nickname = models.CharField(verbose_name='昵称', max_length=180, null=True, blank=True)  # 昵称
    name = models.CharField(verbose_name='姓名', max_length=20)  # 姓名
    mobile = models.CharField(verbose_name='电话', max_length=100)  # 手机
    gender = models.IntegerField(choices=PREUSER_GENDER_CHOICES, verbose_name='性别', null=True, blank=True,
                                 default=0)  # 性别
    wx = models.CharField(verbose_name='微信', max_length=180, null=True, blank=True)  # 微信
    birthday = models.DateField(verbose_name='出生日期', null=True, blank=True)
    province = models.ForeignKey(Province, null=True, blank=True, verbose_name='省')
    city = ChainedForeignKey(
        City,
        chained_field="province",
        chained_model_field="province",
        show_all=False,
        auto_choose=True,
        sort=True,
        null=True,
        blank=True,
        verbose_name='市')
    source = models.ForeignKey("bee_django_crm.Source", verbose_name='来源', null=True, blank=True)  # 来源
    referral_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bee_crm_referral_user', null=True,
                                      blank=True,
                                      verbose_name='原推荐人')  # 推荐人

    referral_user1 = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bee_crm_referral_user1', null=True,
                                       blank=True,
                                       verbose_name='推荐人')  # 推荐人
    referral_user2 = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bee_crm_referral_user2', null=True,
                                       blank=True,
                                       verbose_name='接引人')  # 接引人
    level = models.IntegerField(verbose_name='级别', default=1)  # 级别 1-小白，2-已申请 3-已缴费4-课程卡
    grade = models.IntegerField(verbose_name='意向', null=True, blank=True)  # 意向 1-弱 2-强

    address = models.TextField(verbose_name='地址', null=True, blank=True)

    job = models.CharField(verbose_name='工作', max_length=180, null=True, blank=True)
    email = models.CharField(verbose_name='邮箱', max_length=180, null=True, blank=True)
    hobby = models.TextField(verbose_name='爱好', null=True, blank=True)
    married = models.CharField(verbose_name='婚姻状况', max_length=180, null=True, blank=True)  # 婚否
    children = models.CharField(verbose_name='孩子状况', max_length=180, null=True, blank=True)  # 有几个孩子
    job_info = models.TextField(verbose_name='工作详情', null=True, blank=True)  # 工作详情
    family = models.TextField(verbose_name='家庭详情', null=True, blank=True)  # 家庭情况
    # 缴费记录
    contract_id = models.IntegerField(verbose_name='合同', null=True, blank=True)
    fee = models.FloatField(verbose_name='缴费金额', null=True, blank=True)
    info = models.TextField(verbose_name='备注', null=True, blank=True)
    is_add_coin = models.IntegerField(verbose_name='加缦币', default=0, null=True, blank=True)  # 0-未加缦币，1-已加缦币
    attended_date = models.DateField(verbose_name='入学日期', null=True, blank=True)  # 入学日期
    pay_datetime = models.DateField(verbose_name='缴费日期', null=True, blank=True)  # 缴费日期
    # coupon = models.ForeignKey("other.Coupon", related_name='bee_crm_preUser_coupon', null=True)  # 注册时使用的课程卡
    #
    created_at = models.DateTimeField(auto_now_add=True, null=True)  # 注册时间
    applied_at = models.DateTimeField(null=True)  # 提交申请表时间
    paid_at = models.DateTimeField(null=True)  # 缴费时间
    pay_status = models.IntegerField(default=0, choices=PREUSER_PAY_STATUS_CHOICES, verbose_name='缴费情况')

    class Meta:
        db_table = 'bee_django_crm_preuser'
        app_label = 'bee_django_crm'
        ordering = ["-created_at"]
        verbose_name = 'crm预备用户'
        permissions = (
            ('can_manage_crm', '可以进入crm管理页'),
            ('view_crm_preuser', '可以查看crm用户'),
            ('view_crm_doc', '可以查看帮助文档'),
        )

    def get_absolute_url(self):
        return reverse('bee_django_crm:preuser_detail', kwargs={'pk': self.pk})

    def get_gender(self):
        if not self.gender:
            return ""
        for g in PREUSER_GENDER_CHOICES:
            if self.gender == g[0]:
                return g[1]
        return ""

    def get_grade(self):
        if not self.grade:
            return ""
        for g in PREUSER_GRADE_CHOICES:
            if self.grade == g[0]:
                return g[1]
        return ""

    def get_pay_status(self):
        if not self.pay_status:
            return ""
        for g in PREUSER_PAY_STATUS_CHOICES:
            if self.pay_status == g[0]:
                return g[1]
        return ""

    def get_source(self):
        if not self.source:
            return ""
        return self.source.name

    def get_level(self):
        if not self.level:
            return ""
        for g in PREUSER_LEVEL_CHOICES:
            if self.level == g[0]:
                return g[1]
        return ""

    def __unicode__(self):
        return ("PreUser->name:" + self.name)

    @classmethod
    def init_pay_status(cls):
        users = cls.objects.all()
        for user in users:
            if user.level <= 2:
                user.pay_status = 0
            elif user.level == 3:
                user.pay_status = 1
            user.save()

    # 获取学号，即学生用户名
    def get_user_username(self):
        try:
            return self.userprofile.user.username
        except:
            return ''

    # 获取学生姓名
    def get_user_name(self):
        try:
            return self.userprofile.user.first_name
        except:
            return ''


class RegCode(models.Model):
    reg_number = models.IntegerField(unique=True, null=True)
    reg_name = models.CharField(max_length=180, verbose_name='注册卡号')
    reg_code = models.CharField(max_length=50, verbose_name='注册卡密')
    created_at = models.DateTimeField(default=timezone.now)
    used_at = models.DateTimeField(null=True, blank=True, verbose_name='使用日期')
    used_preuser = models.ForeignKey(PreUser, null=True, blank=True, verbose_name='被谁使用', on_delete=models.SET_NULL)
    course_days = models.IntegerField(null=True, verbose_name='可学习课程天数')

    class Meta:
        db_table = 'bee_django_crm_code'
        app_label = 'bee_django_crm'
        ordering = ["-pk"]
        permissions = (
            ('can_ckeck_code', '可以验证卡密'),
            ('can_get_code', '可以获取卡密'),
        )

    # password_str:密码中出现的字符
    # password_count：密码的位数
    # count：生成数量

    @classmethod
    @transaction.atomic
    def _generate_reg_code(cls, count=0, password_str="1234567890", password_count=10, course_days=None):
        existing_number = cls.objects.all().order_by('reg_number')
        if existing_number.exists():
            number_begin_with = existing_number.last().reg_number + 1
        else:
            number_begin_with = 1

        # csv文件
        file_dir = settings.BASE_DIR + '/media/bee_django_crm/'
        if not os.path.exists(file_dir):
            os.makedirs(file_dir)
        file_name = file_dir + timezone.localtime().strftime("%Y%m%d") + '-' + count.__str__() + ".csv"
        csvfile = open(file_name, 'w')
        writer = csv.writer(csvfile)
        writer.writerow(['number', 'password'])

        # code_list = random.sample(xrange(range_low, range_high), count)
        for code in range(0, count):
            reg_number = number_begin_with
            reg_name = '{:08d}'.format(reg_number)
            first_password_str = password_str.replace("0", '')
            first_password = random.choice(first_password_str)
            _password = cls.generator_password(password_count - 1, password_str)
            reg_code = first_password + _password
            cls.objects.create(reg_code=reg_code, reg_name=reg_name, reg_number=reg_number, course_days=course_days)
            number_begin_with += 1
            writer.writerow([reg_name, reg_code])
        csvfile.close()
        return

    @classmethod
    def generator_password(cls, size, chars):
        return ''.join(random.choice(chars) for _ in range(size))

    # # 生成随机注册码，默认6位数字
    # @classmethod
    # @transaction.atomic
    # def _generate_reg_code(cls, range_low=1000000000000001, range_high=9999999999999999, count=3200,
    #                        number_begin_with=1):
    #     try:
    #         code_list = random.sample(xrange(range_low, range_high), count)
    #         existing_number = cls.objects.order_by('reg_number')
    #         if existing_number.exists():
    #             number_begin_with = existing_number.last().reg_number + 1
    #         else:
    #             number_begin_with = number_begin_with
    #
    #         for code in code_list:
    #             reg_number = number_begin_with
    #             reg_name = '{:08d}'.format(reg_number)
    #             reg_code = code
    #             cls.objects.create(reg_code=reg_code, reg_name=reg_name, reg_number=reg_number)
    #             number_begin_with += 1
    #     except ValueError:
    #         print u'数量超出限定范围'
    #
    #     return count

    @classmethod
    def check_code(cls, reg_name, reg_code):
        code = cls.objects.get(reg_name__exact=reg_name, reg_code__exact=reg_code)

        if code.used_at or code.used_preuser:
            return code.used_preuser, code.used_at
        else:
            return None, None


# 来源
class Source(models.Model):
    name = models.CharField(max_length=60, verbose_name="来源名称")  # 名称
    reg_name = models.CharField(max_length=60, verbose_name="注册页显示名称", null=True, blank=True)  # 注册页显示名称
    created_at = models.DateTimeField(auto_now_add=True)  # 时间
    is_poster = models.BooleanField(default=False, verbose_name='是否海报类型', blank=True)
    is_show = models.BooleanField(default=False, verbose_name='编辑时是否显示', blank=True)

    # reg_unique=models.BooleanField(default=False,verbose_name='是否只能注册一次')

    class Meta:
        db_table = 'bee_django_crm_source'
        app_label = 'bee_django_crm'
        ordering = ['-created_at']
        verbose_name = 'crm渠道'
        permissions = (
            ('view_crm_source', '可以查看渠道'),
            ('can_change_source_name', '可以修改渠道名称'),
        )

    def __unicode__(self):
        return (self.name)

    def get_absolute_url(self):
        return reverse('bee_django_crm:source_list')

    def get_is_poster(self):
        if self.is_poster == True:
            return "是"
        elif self.is_poster == False:
            return "否"

    def get_show_posters(self):
        return self.poster_set.filter(is_show=True)


# 联络记录
class PreUserTrack(models.Model):
    user = models.ForeignKey("bee_django_crm.PreUser", related_name='bee_crm_track_user')  # 追踪人
    created_at = models.DateTimeField(auto_now_add=True)  # 记录时间
    tracked_at = models.DateTimeField(verbose_name='联络时间')  # 追踪时间
    info = models.TextField(verbose_name="详情")  # 详情
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, related_name='bee_crm_created_by_user')  # 操作人

    class Meta:
        db_table = 'bee_django_crm_preuser_track'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return ("PerUserTrack->info:" + self.user.name)

    def get_absolute_url(self):
        return reverse('bee_django_crm:preuser_detail', kwargs={'pk': self.user.pk})


# 申请表问题
class ApplicationQuestion(models.Model):
    name = models.CharField(max_length=180, unique=True, verbose_name='问题')  # 问题
    order_by = models.IntegerField(verbose_name='顺序')  # 顺序
    input_type = models.IntegerField(choices=APPLICATION_QUESTION_INPUT_TYPE_CHOICES, verbose_name='类型')  # 类型
    is_required = models.BooleanField(default=False, verbose_name='是否必填', help_text='只对输入框和单选有效')

    class Meta:
        db_table = 'bee_django_crm_application_question'
        app_label = 'bee_django_crm'
        ordering = ["order_by"]
        verbose_name = 'crm申请表问题'
        permissions = (
            ('view_crm_application', '可以查看申请表问题列表页'),
        )

    def __unicode__(self):
        return ("ApplicationQuestion->question:" + self.name)

    def get_absolute_url(self):
        return reverse('bee_django_crm:application_question_list')

    def get_type_name(self):
        if not self.input_type:
            return ""
        for g in APPLICATION_QUESTION_INPUT_TYPE_CHOICES:
            if self.input_type == g[0]:
                return g[1]
        return ""


# 申请表问题的选项
class ApplicationOption(models.Model):
    question = models.ForeignKey('bee_django_crm.ApplicationQuestion', verbose_name='问题')
    name = models.CharField(verbose_name='选项', max_length=180, unique=True)
    order_by = models.IntegerField(verbose_name='顺序')

    class Meta:
        db_table = 'bee_django_crm_application_options'
        app_label = 'bee_django_crm'
        ordering = ["order_by"]

    def __unicode__(self):
        return ("ApplicationOption->option:" + self.name)


# 学生填的申请表内容# 学生填的申请表内容
class PreUserApplication(models.Model):
    preuser = models.ForeignKey('bee_django_crm.PreUser', related_name='bee_crm_user_applications')
    question = models.ForeignKey('bee_django_crm.ApplicationQuestion')
    answer = models.TextField()

    class Meta:
        db_table = 'bee_django_crm_preuser_application'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return ("PreUserApplication->preuser:" + self.preuser.name)


# 合同
class Contract(models.Model):
    name = models.CharField(verbose_name='合同名称', max_length=180, unique=True)  # 合同名称
    period = models.IntegerField(verbose_name='周期')  # 月／周／天/长期
    duration = models.IntegerField(verbose_name='时长', null=True, blank=True, help_text="如【周期】为【长期】，则不用填写此字段")  # 时长
    price = models.FloatField(verbose_name='金额')  # 金额
    agreement = RichTextField(verbose_name='须知', null=True, app_name='bee_django_crm', model_name='Contract')
    type = models.IntegerField(default=1, choices=((1, "普通合同"), (2, "亲子合同")), verbose_name='合同类型')

    class Meta:
        db_table = 'bee_django_crm_contract'
        app_label = 'bee_django_crm'
        ordering = ["-id"]
        verbose_name = 'crm合同'
        permissions = (
            ('view_crm_contract', '可以查看合同'),
        )

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return reverse('bee_django_crm:contract_list')

    def get_peruser(self):
        preusers = PreUser.objects.filter(preusercontract__contract=self).distinct()
        return preusers

    # 获取合同时长天数显示
    def get_contract_days(self):
        if self.period == 1:
            return self.duration.__str__() + "天"
        elif self.period == 7:
            return self.duration.__str__() + "周"
        elif self.period in [30, 31]:
            return self.duration.__str__() + "月"
        elif self.period == 9999:
            return "长期"

    def get_contract_type(self):
        if self.type == 1:
            return '普通合同'
        elif self.type == 2:
            return '亲子合同'
        return ''


# 用户的合同表
class PreUserContract(models.Model):
    preuser = models.ForeignKey('bee_django_crm.PreUser')
    contract = models.ForeignKey('bee_django_crm.Contract', verbose_name='合同')
    price = models.FloatField(verbose_name='应收金额')  # 金额
    created_at = models.DateTimeField(auto_now_add=True)

    info = models.TextField(null=True, blank=True, verbose_name='备注')
    is_user_agree = models.BooleanField(default=False, verbose_name='用户是否同意')
    study_at = models.DateTimeField(verbose_name='开课日期', null=True, blank=True)
    finish_at = models.DateTimeField(verbose_name='结课日期', null=True, blank=True)
    is_migrate = models.BooleanField(default=False)
    # is_after_check = models.IntegerField(default=False,null=True)
    paid_at = models.DateTimeField(verbose_name='缴费日期', null=True)
    is_checked = models.BooleanField(verbose_name='审核', default=False, blank=True)
    checked_at = models.DateTimeField(null=True)
    checked_by = models.ForeignKey(settings.AUTH_USER_MODEL, null=True)
    after_checked_at = models.DateTimeField(null=True)

    class Meta:
        db_table = 'bee_django_crm_preuser_contract'
        app_label = 'bee_django_crm'
        ordering = ['-created_at']
        permissions = (
            ('view_crm_preuser_contract', '可以查看用户合同'),
        )

    def __unicode__(self):
        return ("PreUserContract->name:" + self.preuser.name)

    def save(self, force_insert=False, force_update=False, using=None,
             update_fields=None):
        if not self.finish_at:
            self.finish_at = self.get_finish_at()
        return super(PreUserContract, self).save(force_insert, force_update, using,
                                                 update_fields)

    def get_finish_at(self):
        # if self.finish_at:
        #     return self.finish_at
        finish_at = None
        contract = self.contract
        if contract.period == 9999:
            finish_at = '2999-12-31 23:59:59+0800'
        else:
            days = contract.period * contract.duration
            if self.study_at:
                finish_at = self.study_at + timedelta(days=days)
        return finish_at

    def get_finish_at_str(self):
        if not self.finish_at.year >= 2999:
            return self.finish_at
        else:
            return '长期无限制'

    @classmethod
    def migrate_to_fee(cls):
        preuser_contract_list = PreUserContract.objects.filter(is_migrate=False)
        for preuser_contract in preuser_contract_list:
            preuser_fee = PreUserFee()
            preuser_fee.preuser = preuser_contract.preuser
            preuser_fee.preuser_contract = preuser_contract
            preuser_fee.price = preuser_contract.price
            preuser_fee.is_checked = preuser_contract.is_checked
            preuser_fee.checked_at = preuser_contract.checked_at
            preuser_fee.checked_by = preuser_contract.checked_by
            preuser_fee.after_checked_at = preuser_contract.after_checked_at
            preuser_fee.paid_at = preuser_contract.paid_at
            preuser_fee.study_at = preuser_contract.study_at
            preuser_fee.save()
            preuser_contract.is_migrate = True
            preuser_contract.save()


PREUSER_FEE_PAY_STATUS_CHOICES = ((1, "全款"), (2, "分期头款"), (3, "分期中"), (4, "分期尾款"))


class PreUserFee(models.Model):
    preuser = models.ForeignKey('bee_django_crm.PreUser')
    preuser_contract = models.ForeignKey(PreUserContract)
    price = models.FloatField(verbose_name='实收金额')  # 金额
    paid_at = models.DateTimeField(verbose_name='缴费日期')
    pay_status = models.IntegerField(default=1, choices=PREUSER_FEE_PAY_STATUS_CHOICES, verbose_name='付款方式及状态')
    is_checked = models.BooleanField(verbose_name='审核', default=False, blank=True)
    checked_at = models.DateTimeField(null=True)
    checked_by = models.ForeignKey(settings.AUTH_USER_MODEL, null=True,related_name='checked_by')
    after_checked_at = models.DateTimeField(null=True)
    info = models.TextField(null=True, blank=True, verbose_name='备注')
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, null=True,related_name='fee_created_by')
    created_at = models.DateTimeField(auto_now_add=True)
    # 弃用
    study_at = models.DateTimeField(verbose_name='开课日期', null=True, blank=True,
                                    help_text="【全款】及【分期头款】时，此字段必填。其他付款方式可不填写")

    class Meta:
        db_table = 'bee_django_crm_preuser_fee'
        app_label = 'bee_django_crm'
        ordering = ['-paid_at', '-created_at']
        permissions = (
            ('add_crm_preuser_fee', '可以添加用户缴费'),
            ('view_crm_preuser_fee', '可以查看用户缴费'),
            ('can_check_crm_preuser_fee', '可以审核用户缴费'),
            ('can_after_checked_fee', '审核缴费后可以后续操作'),
        )

    def __unicode__(self):
        return ("PreUserFee->name:" + self.preuser.name)

    def get_pay_status(self):
        if not self.pay_status:
            return ""
        for g in PREUSER_FEE_PAY_STATUS_CHOICES:
            if self.pay_status == g[0]:
                return g[1]
        return ""

    # 后续成功
    def after_success(self):
        self.after_checked_at = timezone.now()
        self.save()
        # fee_after_success.send(sender=PreUserFee,preuser_fee=self)


# 海报
POSTER_SHOW_CHOICES = ((1, '显示'), (0, '不显示'))


class Poster(models.Model):
    source = models.ForeignKey('bee_django_crm.Source')
    # name = models.CharField(max_length=180, verbose_name='海报名称')
    is_show = models.BooleanField(default=False, verbose_name='是否显示', blank=True)
    # is_clear = models.BooleanField(default=False, verbose_name='是否清空文件', blank=True)
    qrcode_width = models.IntegerField(verbose_name='二维码宽度', null=True, default=0)
    qrcode_height = models.IntegerField(verbose_name='二维码高度', null=True, default=0)
    qrcode_pos_x = models.IntegerField(verbose_name='二维码x轴坐标', null=True, default=0)
    qrcode_pos_y = models.IntegerField(verbose_name='二维码y轴坐标', null=True, default=0)
    qrcode_color = models.CharField(max_length=8, verbose_name='二维码颜色', default='#000000', null=True)
    photo = models.ImageField(upload_to=CRM_POSTER_PHOTO_PATH, null=True)

    class Meta:
        db_table = 'bee_django_crm_poster'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return self.source.name

    def get_temp_image(self):
        return os.path.join(CRM_POSTER_PHOTO_PATH, self.id.__str__() + '_temp.jpg')

    def get_image_count(self):
        image_dir = os.path.join(CRM_POSTER_PHOTO_PATH, self.id.__str__())
        if not os.path.exists(image_dir):
            return 0
        return len([name for name in os.listdir(image_dir) if os.path.isfile(os.path.join(image_dir, name))])

    def get_is_show(self):
        if self.is_show == True:
            return "是"
        elif self.is_show == False:
            return "否"


# =========微信砍价==========
# 微信用户
class WXUser(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name='来源缦客id')
    nickname = models.CharField(max_length=180, verbose_name='微信昵称', null=True)
    avatar_url = models.URLField(verbose_name='头像链接', null=True)
    gender = models.IntegerField(choices=((1, "男"), (2, "女"),), null=True, blank=True, verbose_name='微信性别')
    tel = models.CharField(max_length=20, null=True, blank=True, verbose_name='微信电话')
    city = models.CharField(max_length=20, null=True, blank=True, verbose_name='微信城市')
    province = models.CharField(max_length=20, null=True, blank=True, verbose_name='微信省份')
    country = models.CharField(max_length=20, null=True, blank=True, verbose_name='微信国家')
    open_id = models.CharField(max_length=180, verbose_name='微信openid')
    # source_mkuser_id = models.IntegerField(null=True, verbose_name='来源缦客id')
    created_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        db_table = 'bee_django_crm_wx_user'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        if self.nickname:
            return self.nickname
        else:
            return u'匿名用户' + self.pk.__str__()

    def get_gender(self):
        if self.gender == 1:
            return "男"
        elif self.gender == 2:
            return '女'
        else:
            return ""

    def update_wx_info(self, user_dict):
        self.nickname = user_dict["nickName"]
        self.avatar_url = user_dict["avatarUrl"]
        self.gender = user_dict["gender"]
        self.city = user_dict["city"]
        self.province = user_dict["province"]
        self.country = user_dict["country"]
        self.country = user_dict["country"]
        self.save()
        return

    def to_json(self):
        result = serializer(data=self, output_type='json', datetime_format='string', include_attr=('id', "nickname"))
        result_dict = json.loads(result)
        return json.dumps(result_dict)


# 奖品
class BargainReward(models.Model):
    title = models.CharField(max_length=180, verbose_name='奖励名称')

    class Meta:
        db_table = 'bee_django_bargain_reward'
        app_label = 'bee_django_crm'

    def __unicode__(self):
        return self.title


# 参与记录
class CampaignRecord(models.Model):
    wxuser = models.ForeignKey(WXUser, verbose_name='微信用户')
    reward = models.ForeignKey(BargainReward, verbose_name='奖品')
    count = models.IntegerField(verbose_name='砍价次数', default=0)
    result = models.FloatField(verbose_name='砍价结果', default=0)
    status = models.IntegerField(choices=((1, "进行中"), (2, "已完成"), (3, "已消费"),), default=1)
    share_qrcode = models.ImageField(upload_to='bee_django_crm/gift/campaign_record/share_qrcode', null=True, blank=True,
                                     verbose_name='小程序二维码')
    created_at = models.DateTimeField(auto_now_add=True)
    bind_user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name='红包发放用户账号')
    bind_preuser = models.ForeignKey(PreUser, null=True, blank=True, verbose_name='红包发放新peruser账号')
    is_mk = models.NullBooleanField(verbose_name='是否是老缦客',null=True)
    history = models.TextField(verbose_name='历史记录', null=True, blank=True)

    class Meta:
        unique_together = (('wxuser', 'reward'),)
        db_table = 'bee_django_crm_bargain_campaign_record'
        app_label = 'bee_django_crm'
        ordering = ["-created_at"]
        permissions = (
            ('view_campaign_record_list', 'view_campaign_record_list'),  # 查看参加活动列表
            ('view_campaign_record_detail', 'view_campaign_record_detail'),  # 查看参加活动详情页
        )

    def __unicode__(self):
        return self.pk.__str__()

    def get_status(self):
        if self.status == 1:
            return '进行中'
        elif self.status == 2:
            return '已完成'
        elif self.status == 3:
            return '已消费'
        return ''

    def add_wxuser(self):
        wxuser = WXUser.objects.get(id=self.wxuser.id)
        wxuser_dict = {"nickname": wxuser.nickname, "id": wxuser.id, "avatar_url": wxuser.avatar_url}
        setattr(self, 'wxuser_info', wxuser_dict)

    def add_bind_name(self):
        if self.bind_user:
            bind_name = self.bind_user.first_name[0] + "***"
        elif self.bind_preuser:
            bind_name = self.bind_preuser.name[0] + "***"
        else:
            bind_name = None
        setattr(self, 'bind_name', bind_name)

    def to_json(self):
        self.add_wxuser()
        self.add_bind_name()
        result = serializer(data=self, output_type='json', datetime_format='string',
                            include_attr=('id', "count", "result", "status", "wxuser_info"))
        result_dict = json.loads(result)
        return json.dumps(result_dict)

    def update_result(self):
        record_list = BargainRecord.objects.filter(campaign_record=self).aggregate(Sum('result'))
        sum = record_list["result__sum"]
        self.result = sum
        if sum >= 1000:
            self.status = 2
        self.save()
        return

    def update_history(self, request_user_name, info=None):
        now_str = timezone.localtime(timezone=LOCAL_TIMEZONE).strftime("%Y-%m-%d %H:%M:%S")
        history = u"<p>由【" + request_user_name + u"】于【" + now_str + u"】修改"
        if info:
            history += u"：" + info
        history += "</p>"
        if self.history:
            self.history += history
        else:
            self.history = history
        self.save()

    # def update_qrcode(self, url, parameters):
    #     try:
    #         from bee_django_message.models import WeixinServiceAccessToken
    #     except Exception as e:
    #         return e
    #     token = WeixinServiceAccessToken.get_token(2)
    #     url = "https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=" + token
    #     data = json.dumps(parameters)
    #     res_data = requests.post(url=url, data=data, timeout=10, headers={'content-type': 'application/json'})
    #     if res_data.status_code == 200:
    #         return res_data.content
    #     else:
    #         return None
    #
    #     res = api_post(url, {"page": "pages/index/index", "scene": "a=1"}, )
    #     try:
    #         _dict = json.loads(res)
    #         print _dict
    #         if hasattr(_dict, 'errcode'):
    #             print ('error')
    #             return
    #     except:
    #         pass


# 砍价记录
class BargainRecord(models.Model):
    campaign_record = models.ForeignKey(CampaignRecord, verbose_name='参与记录')
    # bargain_wxuser = models.ForeignKey(WXUser,verbose_name='被助力的微信用户',related_name='bargain_wxuser')
    op_wxuser = models.ForeignKey(WXUser, verbose_name='助力的微信用户', related_name='op_wxuser')
    result = models.FloatField(verbose_name='砍价结果')
    wx_nickname = models.CharField(max_length=180, verbose_name='微信昵称', null=True)
    wx_avatar_url = models.URLField(verbose_name='头像链接', null=True)
    created_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        unique_together = (('campaign_record', 'op_wxuser'),)
        db_table = 'bee_django_crm_bargain_record'
        app_label = 'bee_django_crm'
        ordering = ["-created_at"]

    def __unicode__(self):
        return self.pk.__str__()

    def add_wxuser(self):
        wxuser = WXUser.objects.get(id=self.op_wxuser_id)
        if wxuser.nickname:
            if wxuser.nickname.__len__() <= 2:
                nickname = wxuser.nickname[0] + '*'
            else:
                nickname = wxuser.nickname[0] + '*' + wxuser.nickname[-1]
        else:
            nickname = '微信用户'
        wxuser_dict = {"nickname": nickname, "avatar_url": wxuser.avatar_url}
        setattr(self, 'op_wxuser_info', wxuser_dict)

    def re_name(self):
        if self.wx_nickname.__len__() <= 2:
            re_nickname = self.wx_nickname[0] + '***'
        else:
            re_nickname = self.wx_nickname[0] + '**' + self.wx_nickname[-1]
        setattr(self, 'wx_nickname', re_nickname)

    def to_json(self):
        self.add_wxuser()
        result = serializer(data=self, output_type='json', datetime_format='string',
                            include_attr=('id', "campaign_record_id", "result", "created_at"))
        result_dict = json.loads(result)
        return json.dumps(result_dict)

    def save(self, force_insert=False, force_update=False, using=None,
             update_fields=None):
        super(BargainRecord, self).save(force_insert, force_update, using, update_fields)
        self.campaign_record.update_result()
        return



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-12 06:36
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0041_auto_20191210_1346'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='campaignrecord',
            options={'ordering': ['-created_at']},
        ),
        migrations.RemoveField(
            model_name='wxuser',
            name='source_mkuser_id',
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='status',
            field=models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe5\xae\x8c\xe6\x88\x90'), (3, b'\xe5\xb7\xb2\xe6\xb6\x88\xe8\xb4\xb9')], default=1),
        ),
        migrations.AlterField(
            model_name='wxuser',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x9d\xa5\xe6\xba\x90\xe7\xbc\xa6\xe5\xae\xa2id'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-06 09:05
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0039_wxuser_source_mkuser_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaignrecord',
            name='bind_preuser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUser', verbose_name=b'\xe7\xba\xa2\xe5\x8c\x85\xe5\x8f\x91\xe6\x94\xbe\xe6\x96\xb0peruser\xe8\xb4\xa6\xe5\x8f\xb7'),
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='bind_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name=b'\xe7\xba\xa2\xe5\x8c\x85\xe5\x8f\x91\xe6\x94\xbe\xe7\x94\xa8\xe6\x88\xb7\xe8\xb4\xa6\xe5\x8f\xb7'),
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='is_mk',
            field=models.BooleanField(default=False, verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe6\x98\xaf\xe8\x80\x81\xe7\xbc\xa6\xe5\xae\xa2'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='city',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe5\x9f\x8e\xe5\xb8\x82'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='country',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe5\x9b\xbd\xe5\xae\xb6'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='gender',
            field=models.IntegerField(blank=True, choices=[(1, b'\xe7\x94\xb7'), (2, b'\xe5\xa5\xb3')], null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x80\xa7\xe5\x88\xab'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='province',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x9c\x81\xe4\xbb\xbd'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='tel',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xb5\xe8\xaf\x9d'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os, requests, json, random, datetime
from django.db import transaction
from django.shortcuts import HttpResponse
from django.conf import settings
from django.http import JsonResponse
from django.views.decorators.csrf import csrf_exempt
from django.contrib.auth import authenticate
from dss.Serializer import serializer
from django.http import JsonResponse
from django.utils import timezone
from django.views.generic import ListView, DetailView, TemplateView
from dss.Mixin import MultipleJsonResponseMixin, JsonResponseMixin, FormJsonResponseMixin
from django.contrib.auth import authenticate
from django.contrib.auth import get_user_model

from .models import WXUser, CampaignRecord, BargainRecord, PreUser
from .utils import LOCAL_TIMEZONE, create_wxapp_qrcode, encode, decode, check_bargain_create

JSCODE2SESSION_URL = 'https://api.weixin.qq.com/sns/jscode2session?grant_type=authorization_code'
APPID = "wxcb508410e0530d63"
APPSECRET = "1eb1e52b42e36f3baa2a9ef0158e6597"
User = get_user_model()


def test(request):
    import requests
    import os

    pid = os.fork()
    if pid == 0:
        a = requests.post('http://127.0.0.1:8000/crm/wxapp/a')

    else:
        b = requests.post('http://127.0.0.1:8000/crm/wxapp/a')

    # os._exit(0)
    return


@csrf_exempt
@transaction.atomic
def a(request):
    z = BargainRecord.objects.filter(op_wxuser_id=16, campaign_record_id=35)
    if z.exists():
        print ("error1")
    try:
        BargainRecord.objects.create(op_wxuser_id=16, campaign_record_id=35, result=11,
                                     wx_nickname="aaa", wx_avatar_url="http://aaa")
        print ("ok")
    except:
        print ("error2")
    return JsonResponse(data={
        'errCode': 0,
        'errMsg': "成功",
    })


def login(request):
    code = request.GET.get('code')
    source_mkuser_id = request.GET.get('source_mkuser_id')
    campaign_record_id = request.GET.get('campaign_record_id')

    url = JSCODE2SESSION_URL + '&appid=' + APPID + '&secret=' + APPSECRET + '&js_code=' + code
    # login(request, user)
    r = requests.get(url).json()
    open_id = r['openid']
    wxuser, is_create = WXUser.objects.get_or_create(open_id=open_id)
    if is_create:
        if source_mkuser_id:
            user = User.objects.get(id=source_mkuser_id)
            wxuser.user = user
            wxuser.save()
        elif campaign_record_id:
            campaign = CampaignRecord.objects.get(id=campaign_record_id)
            wxuser.user = campaign.wxuser.user
            wxuser.save()
    wxuser_token = encode(wxuser.pk.__str__())
    return JsonResponse(data={
        'errCode': 0,
        "wxuser_token": wxuser_token,
        'wxuser': wxuser.to_json(),
        'errMsg': "成功",
    })


#
# def share_image(request,reward_id):
#     print ("init", hasattr(settings, "a"))
#     print ("init", hasattr(settings, "REFERRAL_QRCODE_PRE_URL"))
#     print ("share_image")
#     try:
#         from bee_django_message.models import WeixinServiceAccessToken
#     except Exception as e:
#         return HttpResponse(e)
#     token = WeixinServiceAccessToken.get_token(2)
#     url="https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token="+token
#     res = api_post(url,{"page":"pages/index/index","scene":"a=1"})
#     try:
#         _dict = json.loads(res)
#         print _dict
#         if hasattr(_dict,'errcode'):
#             print ('error')
#             return
#     except:
#         pass
#     from .utils import merge_img
# error, msg, img = merge_img(referral_base_path=os.path.join(settings.BASE_DIR,'bee_django_crm','static',"bee_django_crm",'img','preuser_done.jpg'),
#                             qrcode_img=res, qrcode_pos=(0, 0),
#                             qrcode_size=(200, 200))
# print error,msg,img
# if img:
#     response = HttpResponse(content_type='image/jpg')
#     img.save(response, "JPEG")
#     return response

# dir = os.path.join(settings.BASE_DIR,'media','crm')
# if not os.path.exists(dir):
#     os.makedirs(dir)
# with open(os.path.join(settings.BASE_DIR,dir,'bb.jpg'),"wb") as f:
#     f.write(res)
#
# return


def campaign_my_detail(request, wxuser_id, reward_id):
    campaign_records = CampaignRecord.objects.filter(wxuser_id=wxuser_id, reward_id=reward_id)
    if campaign_records.exists():
        campaign_info = campaign_records.first().to_json()
    else:
        campaign_info = None
    return JsonResponse(data={
        'errCode': 0,
        "campaign_info": campaign_info,
        'errMsg': "成功",
    })


class CampaignRecordDetail(JsonResponseMixin, DetailView):
    model = CampaignRecord
    datetime_type = 'string'
    pk_url_kwarg = 'pk'

    def get_object(self, queryset=None):
        campaign_record = CampaignRecord.objects.get(id=self.kwargs["pk"])
        # 补充分享图
        if not campaign_record.share_qrcode:
            img_dir = os.path.join(settings.BASE_DIR, 'media', "bee_django_crm", "gift", "campaign_record",
                                   "share_qrcode")
            img_name = campaign_record.pk.__str__() + ".jpg"
            errcode, errmsg, image = create_wxapp_qrcode(
                parameters={"page": "pages/index/index", "scene": "0_" + campaign_record.wxuser.user_id.__str__()},
                img_dir=img_dir, img_name=img_name)
            if errcode == 0:
                campaign_record.share_qrcode = 'bee_django_crm/gift/campaign_record/share_qrcode/' + img_name
                campaign_record.save()
        campaign_record.add_wxuser()
        campaign_record.add_bind_name()
        return campaign_record


@csrf_exempt
def campaign_record_create(request):
    # class CampaignRecordCreate(TemplateView):

    # def post(self, request, *args, **kwargs):
    wxuser_id = request.POST.get("wxuser_id")
    reward_id = request.POST.get("reward_id")
    user_info = request.POST.get("user_info")
    try:
        wxuser = WXUser.objects.get(id=wxuser_id)
    except:
        return JsonResponse(data={
            'errCode': 1,
            'errMsg': '参数错误'
        })

    record, is_create = CampaignRecord.objects.get_or_create(wxuser=wxuser, reward_id=reward_id)

    # 更新微信信息
    try:
        user_dict = json.loads(user_info)
        wxuser = WXUser.objects.get(id=record.wxuser_id)
        wxuser.update_wx_info(user_dict)
    except Exception as e:
        print (e)
        pass

    if is_create == True:
        #  生成分享二维码
        try:
            img_dir = os.path.join(settings.BASE_DIR, 'media', "bee_django_crm", "gift", "campaign_record", "share_qrcode")
            img_name = record.pk.__str__() + ".jpg"
            errcode, errmsg, image = create_wxapp_qrcode(
                parameters={"page": "pages/index/index", "scene": "0_" + record.wxuser.user_id.__str__()},
                img_dir=img_dir, img_name=img_name)
            if errcode == 0:
                record.share_qrcode = 'bee_django_crm/gift/campaign_record/share_qrcode/' + img_name
                record.save()
        except:
            pass
        # 自己先砍一刀
        # 添加前检查
        errcode, errmsg, r = check_bargain_create(record, wxuser)
        if errcode == 0:
            try:
                bargain_result = BargainRecord.objects.create(op_wxuser=wxuser, campaign_record=record, result=r,
                                                              wx_nickname=wxuser.nickname,
                                                              wx_avatar_url=wxuser.avatar_url)
            except:
                pass

    return JsonResponse(data={
        'errCode': 0,
        "campaign_info": record.to_json(),
        'errMsg': "成功",
    })


@csrf_exempt
def campaign_bind_user(request):
    campaign_id = request.POST.get("campaign_id")
    username = request.POST.get("username")
    password = request.POST.get("password")
    name = request.POST.get("name")
    try:
        campaign = CampaignRecord.objects.get(id=campaign_id)
    except:
        return JsonResponse(data={
            'errCode': 1,
            'errMsg': "参数错误",
        })
    if campaign.bind_user or campaign.bind_preuser:
        return JsonResponse(data={
            'errCode': 2,
            'errMsg': "已绑定过账号"
        })
    user = authenticate(username=username, password=password)
    if user is None:
        return JsonResponse(data={
            'errCode': 3,
            'errMsg': "用户名或密码错误"
        })
    if not user.first_name == name:
        return JsonResponse(data={
            'errCode': 4,
            'errMsg': "信息输入错误"
        })

    records = CampaignRecord.objects.filter(bind_user=user)
    if records.exists():
        return JsonResponse(data={
            'errCode': 5,
            'errMsg': "该用户已绑定过"
        })
    campaign.bind_user = user
    campaign.is_mk = True
    campaign.save()
    return JsonResponse(data={
        'errCode': 0,
        'errMsg': "成功"
    })


@csrf_exempt
def campaign_bind_preuser(request):
    campaign_id = request.POST.get("campaign_id")
    name = request.POST.get("name")
    tel = request.POST.get("tel")
    source_id = request.POST.get("source_id")
    # referral_user_id = request.POST.get("source_mkuser_id")

    try:
        campaign = CampaignRecord.objects.get(id=campaign_id)
    except:
        return JsonResponse(data={
            'errCode': 1,
            'errMsg': "参数错误",
        })
    if campaign.bind_user or campaign.bind_preuser:
        return JsonResponse(data={
            'errCode': 2,
            'errMsg': "已绑定过账号"
        })
    try:
        user = campaign.wxuser.user
    except:
        user = None
    preuser = PreUser.objects.create(nickname=name, name=name, mobile=tel, source_id=source_id, referral_user1=user,
                                     level=1)
    campaign.bind_preuser = preuser
    campaign.is_mk = False

    campaign.save()
    return JsonResponse(data={
        'errCode': 0,
        'errMsg': "成功"
    })


class BargainList(MultipleJsonResponseMixin, ListView):
    model = BargainRecord
    query_set = None
    paginate_by = 100
    datetime_type = 'string'

    def get_queryset(self):
        campaign_id = self.kwargs["campaign_id"]
        bargain_list = BargainRecord.objects.filter(campaign_record_id=campaign_id)
        map(self.rename, bargain_list)
        # map(self.add_attr, bargain_list)
        return bargain_list

    def rename(self, bargain_record):
        bargain_record.re_name()

    def add_attr(self, bargain_record):
        bargain_record.add_wxuser()
        # wxuser = WXUser.objects.get(id=bargain_record.op_wxuser_id)
        # wxuser_dict={"nickname":wxuser.nickname}
        # setattr(bargain_record, 'op_wxuser_info', wxuser_dict)


class BargainRecordDetail(JsonResponseMixin, DetailView):
    model = BargainRecord
    datetime_type = 'string'
    pk_url_kwarg = 'pk'

    # def get_object(self, queryset=None):
    #     bargain_record = BargainRecord.objects.get(id=self.kwargs["pk"])
    #     bargain_record.add_wxuser()
    #     return campaign_record


@csrf_exempt
def bargain_record_create(request):
    wxuser_id = request.POST.get("wxuser_id")
    wxuser_token = request.POST.get("wxuser_token")
    campaign_id = request.POST.get("campaign_id")
    user_info = request.POST.get("user_info")

    try:
        campaign = CampaignRecord.objects.get(id=campaign_id)
    except:
        return JsonResponse(data={
            'errCode': 1,
            'errMsg': "参数错误"
        })

    try:
        op_wxuser = WXUser.objects.get(id=wxuser_id)
    except:
        return JsonResponse(data={
            'errCode': 1,
            'errMsg': "参数错误"
        })

    try:
        id_str = decode(wxuser_token)
    except:
        return JsonResponse(data={
            'errCode': 6,
            'errMsg': "token错误"
        })
    if not id_str == wxuser_id.__str__():
        return JsonResponse(data={
            'errCode': 6,
            'errMsg': "token错误"
        })

    # 添加前检查
    errcode, errmsg, r = check_bargain_create(campaign, op_wxuser)
    if not errcode == 0:
        return JsonResponse(data={
            'errCode': errcode,
            'errMsg': errmsg
        })

    user_dict = json.loads(user_info)
    try:
        bargain_result = BargainRecord.objects.create(op_wxuser_id=wxuser_id, campaign_record=campaign, result=r,
                                                      wx_nickname=user_dict["nickName"],
                                                      wx_avatar_url=user_dict["avatarUrl"])
    except:
        return JsonResponse(data={
            'errCode': 8,
            'errMsg': "错误"
        })
    # 更新微信信息
    try:
        wxuser = WXUser.objects.get(id=wxuser_id)
        wxuser.update_wx_info(user_dict)
    except Exception as e:
        print (e)
        pass
    return JsonResponse(data={
        'errCode': 0,
        "bargain_result": r,
        'errMsg': "成功",
    })



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-02 11:30
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0036_wxuser_avatar_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='bargainrecord',
            name='wx_avatar_url',
            field=models.URLField(null=True, verbose_name=b'\xe5\xa4\xb4\xe5\x83\x8f\xe9\x93\xbe\xe6\x8e\xa5'),
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='wx_nickname',
            field=models.CharField(max_length=180, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x98\xb5\xe7\xa7\xb0'),
        ),
        migrations.AlterField(
            model_name='wxuser',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 05:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0032_auto_20191127_1721'),
    ]

    operations = [
        migrations.CreateModel(
            name='BargainRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('result', models.FloatField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'db_table': 'bee_django_crm_bargain_record',
            },
        ),
        migrations.CreateModel(
            name='BargainReward',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name=b'\xe5\xa5\x96\xe5\x8a\xb1\xe5\x90\x8d\xe7\xa7\xb0')),
            ],
            options={
                'db_table': 'bee_django_bargain_reward',
            },
        ),
        migrations.CreateModel(
            name='CampaignRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('count', models.IntegerField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\xac\xa1\xe6\x95\xb0')),
                ('result', models.FloatField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c')),
                ('status', models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe6\x8f\x90\xe5\x8f\x96')], default=1)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('reward', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.BargainReward', verbose_name=b'\xe5\xa5\x96\xe5\x93\x81')),
                ('wxuser', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.WXUser', verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xa8\xe6\x88\xb7')),
            ],
            options={
                'db_table': 'bee_django_crm_bargain_campaign_record',
            },
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='campaign_record',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.CampaignRecord', verbose_name=b'\xe5\x8f\x82\xe4\xb8\x8e\xe8\xae\xb0\xe5\xbd\x95'),
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='op_wxuser',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='op_wxuser', to='bee_django_crm.WXUser', verbose_name=b'\xe5\x8a\xa9\xe5\x8a\x9b\xe7\x9a\x84\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xa8\xe6\x88\xb7'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-27 09:15
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0030_auto_20191122_1324'),
    ]

    operations = [
        migrations.CreateModel(
            name='WXUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nickname', models.CharField(max_length=180, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x98\xb5\xe7\xa7\xb0')),
                ('open_id', models.CharField(max_length=180, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1openid')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'bee_django_crm_wx_user',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-13 09:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0042_auto_20191212_1436'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='campaignrecord',
            options={'ordering': ['-created_at'], 'permissions': (('view_campaign_record_list', 'view_campaign_record_list'), ('view_campaign_record_detail', 'view_campaign_record_detail'))},
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='history',
            field=models.TextField(blank=True, null=True, verbose_name=b'\xe5\x8e\x86\xe5\x8f\xb2\xe8\xae\xb0\xe5\xbd\x95'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-10 05:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0040_auto_20191206_1705'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='bargainrecord',
            unique_together=set([('campaign_record', 'op_wxuser')]),
        ),
        migrations.AlterUniqueTogether(
            name='campaignrecord',
            unique_together=set([('wxuser', 'reward')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 06:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0033_auto_20191128_1312'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='count',
            field=models.IntegerField(default=0, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\xac\xa1\xe6\x95\xb0'),
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='result',
            field=models.FloatField(default=0, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-22 05:24
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0029_auto_20190923_1715'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contract',
            name='agreement',
            field=bee_django_richtext.custom_fields.RichTextField(app_name=b'bee_django_crm', emotion=False, image_max_size=2, img=False, model_name=b'Contract', null=True, text_min_length=5, undo_redo=False, verbose_name=b'\xe9\xa1\xbb\xe7\x9f\xa5'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-06 08:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0038_auto_20191205_1635'),
    ]

    operations = [
        migrations.AddField(
            model_name='wxuser',
            name='source_mkuser_id',
            field=models.IntegerField(null=True, verbose_name=b'\xe6\x9d\xa5\xe6\xba\x90\xe7\xbc\xa6\xe5\xae\xa2id'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-20 09:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0043_auto_20191213_1700'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='is_mk',
            field=models.NullBooleanField(verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe6\x98\xaf\xe8\x80\x81\xe7\xbc\xa6\xe5\xae\xa2'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 10:29
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0034_auto_20191128_1411'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bargainrecord',
            options={'ordering': ['-created_at']},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-25 09:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0045_auto_20191220_1903'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='share_qrcode',
            field=models.ImageField(blank=True, null=True, upload_to=b'bee_django_crm/gift/campaign_record/share_qrcode', verbose_name=b'\xe5\xb0\x8f\xe7\xa8\x8b\xe5\xba\x8f\xe4\xba\x8c\xe7\xbb\xb4\xe7\xa0\x81'),
        ),
    ]
